@@ -6,6 +6,7 @@ class FindExample(Document):
     structure = {
         'name': basestring,
         'age': int,
+        'crap': {basestring: int},
     }
 
     __database__ = 'test'
@@ -28,6 +29,7 @@ def main():
         {'name': 'Bob', 'age': 32},
         {'name': 'Carl', 'age': 41},
         {'name': 'Donna', 'age': 35},
+        {'name': 'Earl', 'crap': {1:2, 2:3}},
     ]
     docs = [conn.models.FindExample(doc) for doc in docs]
     for doc in docs:
