@@ -3,6 +3,7 @@ Schema
 ======
 
 The core schema validation logic.
+
 """
 
 from scalymongo.errors import SchemaError, ValidationError
@@ -17,6 +18,7 @@ class UpdatingList(list):
     structure that does not rely on hashing.  This wrapper class just tacks the
     :meth:`update` method onto a list to make them interoperable with ``set``
     and ``dict`` instances.
+
     """
     update = list.extend
 
@@ -79,9 +81,9 @@ def _make_single_conversion(value):
     if isinstance(value, type) and issubclass(value, SchemaDocument):
         return value
 
+
 def find_shard_index(indexes):
-    """Find the shard key and validate index properties.
-    """
+    """Find the shard key and validate index properties."""
     shard_key_indexes = [index for index in indexes
                          if index.get('shard_key')]
     if not shard_key_indexes:
@@ -111,6 +113,7 @@ class SchemaDocument(ConversionDict):
 
     This class also uses the structure information to wrap the values of
     embedded non-primatives.
+
     """
 
     __metaclass__ = SchemaMetaclass
@@ -134,13 +137,15 @@ def validate_structure(body, structure):
 def validate_single_field(path, value, expected_type):
     """Validate a single field's value.
 
-    This is the callback validator used by the :meth validate_structure: to
+    This is the callback validator used by the :func:`validate_structure` to
     check individual field values.
+
     """
     if not is_field_of_expected_type(value, expected_type):
         raise ValidationError(
-            "Position {0!r} was declared to be {1}, but encountered value {2}"
-            .format(path, expected_type, value))
+            "Position {0!r} was declared to be {1!r},"
+            " but encountered value {2!r}".format(
+                path, expected_type, value))
 
 
 def is_field_of_expected_type(value, expected_type):
@@ -153,8 +158,7 @@ def is_field_of_expected_type(value, expected_type):
 
 
 def validate_required_fields(fields, required):
-    """Ensure that all `required` fields are present in `fields`.
-    """
+    """Ensure that all `required` fields are present in `fields`."""
     missing = required.difference(fields.keys())
     if missing:
         raise ValidationError(
@@ -163,8 +167,7 @@ def validate_required_fields(fields, required):
 
 
 def validate_update_modifier(spec, structure):
-    """Ensure that all operations are valid for the specified structure.
-    """
+    """Ensure that all operations are valid for the specified structure."""
     for modifier, args in spec.iteritems():
         validate_single_modifier(modifier, args, structure)
 
@@ -177,6 +180,7 @@ def validate_single_modifier(modifier, args, structure):
     :param structure: Is the structure of the document that the
         modification should be applied to.  This is used to determine whether
         or not the modification is sane for this document.
+
     """
     if modifier == '$set':
         return validate_structure(args, structure)
@@ -226,7 +230,7 @@ def _validate_field_modifier(modifier, field_type, value):
 def _validate_inc_modifier(field_type, value):
     if field_type not in [int, long, float]:
         raise ValidationError(
-            'Cannot increment non-numeric field of declared as {0}'.format(
+            'Cannot increment non-numeric field declared as {0}'.format(
                 repr(field_type)))
 
 
@@ -241,7 +245,16 @@ def _make_single_value_array_modifier_validator(action_name):
                     action_name, repr(field_type)))
 
         array_type = field_type[0]
-        if not is_field_of_expected_type(value, array_type):
+        if isinstance(array_type, dict):
+            # It's an embedded document.
+            try:
+                validate_structure(value, array_type)
+            except ValidationError as ex:
+                raise ValidationError(
+                    'Cannot {0} value {1!r} onto array of {2!r}: {3}'.format(
+                        action_name, value, array_type, ex))
+
+        elif not is_field_of_expected_type(value, array_type):
             raise ValidationError(
                 'Cannot {0} value {1} onto array of {2}'.format(
                     action_name, repr(value), repr(array_type)))
