@@ -1,12 +1,11 @@
 class OR(object):
-    """Specify that a value should be one of several types.
-    """
+    """Specify that a value should be one of several types."""
 
     def __init__(self, *args):
         self.valid_types = tuple(sorted(args))
 
     def evaluate(self, value):
-        """Determine if :param value: meets this operator's criteria."""
+        """Determine if `value` meets this operator's criteria."""
         return isinstance(value, self.valid_types)
 
     def __eq__(self, other):
@@ -22,15 +21,16 @@ class OR(object):
 class IS(object):
     """Specify that a value should one of several *exact values*.
 
-    This operator uses a ``set`` for fast checking so any values must be
+    This operator uses a :class:`set` for fast checking so any values must be
     hashable.
+
     """
 
     def __init__(self, *args):
         self.valid_values = set(args)
 
     def evaluate(self, value):
-        """Determine if :param value: meets this operator's criteria."""
+        """Determine if `value` meets this operator's criteria."""
         return value in self.valid_values
 
     def __eq__(self, other):
